@@ -5,6 +5,7 @@ use strict;
 use File::Spec::Functions qw/catfile catdir splitpath/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
+use File::Copy 'copy';
 use File::Copy::Recursive qw/rcopy/;
 use File::Path qw/make_path remove_tree/;
 use List::MoreUtils qw/uniq firstidx/;
@@ -12,7 +13,7 @@ use Module::Info;
 
 our %REQUIRE_OPTIONS = ( import => [qw/source/] );
 
-use base qw/Class::Accessor::Fast/;
+use base qw/Shipwright::Base/;
 __PACKAGE__->mk_accessors(qw/repository log/);
 
 =head1 NAME
@@ -95,7 +96,7 @@ sub _install_module_build {
     my $dir = shift;
     my $module_build_path = catdir( $dir, 'inc', 'Module', );
     make_path( catdir( $module_build_path, 'Build' ) );
-    rcopy( Module::Info->new_from_module('Module::Build')->file,
+    copy( Module::Info->new_from_module('Module::Build')->file,
             $module_build_path ) or confess_or_die "copy Module/Build.pm failed: $!";
     rcopy(
         catdir(
@@ -105,6 +106,37 @@ sub _install_module_build {
         catdir( $module_build_path, 'Build' )
       )
       or confess_or_die "copy Module/Build failed: $!";
+
+    # Module::Build needs Module::Metadata, Perl::OSType
+    make_path( catdir( $dir, 'inc', 'Module::Metadata' ) );
+    make_path( catdir( $dir, 'inc', 'Perl' ) );
+    copy(
+        Module::Info->new_from_module('Perl::OSType')->file,
+        catdir( $dir, 'inc', 'Perl' ) )
+          or confess_or_die "copy Perl/OSType.pm failed: $!";
+
+    copy(
+        Module::Info->new_from_module('Module::Metadata')->file,
+        catdir( $dir, 'inc', 'Module' ) )
+          or confess_or_die "copy Module/Metadata.pm failed: $!";
+# Module::Metadata 1.02 requires version 0.87+, which isn't in perl core yet
+# we can't simply copy version.pm to inc because it's not plain perl.
+# so here we do a maybe dangerous thing, hack Module::Metadata to not require
+# version 0.87+
+# so is Module::Build
+    my @files = ( catfile( $dir, 'inc', 'Module', 'Metadata.pm' ),
+      catfile( $dir, 'inc', 'Module', 'Build', 'Version.pm' ) );
+
+    for my $file ( @files ) {
+        open my $fh, '<', $file or die $!;
+        local $/;
+        my $content = <$fh>;
+        $content =~ s!use version.*?;!use version;!;
+        chmod 0755, $file unless -w $file;
+        open $fh, '>', $file or die $!;
+        print $fh $content;
+        close $fh;
+    }
 }
 
 sub _install_yaml_tiny {
